@@ -1,5 +1,4 @@
 from controller import *
-from counter import Counter
 from helper import Helper
 from source import Source
 from each import Each
@@ -25,7 +24,7 @@ class OperationHandler:
   def node(self):
     return self._node
 
-  def build_multilang_operation(self, op_type, *args):
+  def build_multilang_operation(self, op_type, *args, **kwargs):
     if op_type == "source":
       self._node = Source(self._app)
     elif op_type == "each":
@@ -47,7 +46,8 @@ class OperationHandler:
     else:
       raise "unknown type"
 
-    self._node.build_node(*args)
+    # kwargs
+    self._node.build_node(*args, **kwargs)
     return self
 
   def build_jvm_operation(self, op_type, *args):
@@ -88,7 +88,7 @@ class OperationHandler:
           node_hash[par] = eval("self._node._"+par)
       # Always add options if they are not null
       if hasattr(self._node, "_options"):
-        node_hash["config"] = self._node._options 
+        node_hash["config"] = self._node._options
       Helper.write_node_to_file(node_hash, self._app._socket)
 
       for stream in self._arc_hash_streams:
