@@ -7,9 +7,10 @@ class Stream:
     self._app = app
     self._previous_node_name = previous_node_name
 
-  def each(self, name=None, emits=None, output_format="replace", prepare=None, execute=None, parallelism=None):
+
+  def each(self, *args, **kwargs):
     op = OperationHandler(self._app, self.__class__)
-    streams = op.build_multilang_operation("each", name, emits, output_format, prepare, execute, parallelism)\
+    streams = op.build_multilang_operation("each", *args, **kwargs)\
                  .add_operation_properties_to_info("name", "type", "output_format")\
                  .add_optional_operation_properties_to_info("parallelism")\
                  .create_arc_info_from_stream(self)\
@@ -17,9 +18,9 @@ class Stream:
                  .get_output_streams()
     return streams
 
-  def filter(self, name=None, emits=None, prepare=None, keep=None, parallelism=None):
+  def filter(self, *args, **kwargs):
     op = OperationHandler(self._app, self.__class__)
-    streams = op.build_multilang_operation("filter", name, emits, prepare, keep, parallelism)\
+    streams = op.build_multilang_operation("filter", *args, **kwargs)\
                 .add_operation_properties_to_info("name", "type")\
                 .add_optional_operation_properties_to_info("parallelism")\
                 .create_arc_info_from_stream(self)\
@@ -27,9 +28,9 @@ class Stream:
                 .get_output_streams()
     return streams
 
-  def group_by(self, name=None, emits=None, fields=None, prepare=None, begin_group=None, aggregate=None, end_group=None, parallelism=None):
+  def group_by(self, *args, **kwargs):
     op = OperationHandler(self._app, self.__class__)
-    streams = op.build_multilang_operation("group_by", name, emits, fields, prepare, begin_group, aggregate, end_group, parallelism)\
+    streams = op.build_multilang_operation("group_by", *args, **kwargs)\
                 .add_operation_properties_to_info("name", "type", "group_by")\
                 .add_optional_operation_properties_to_info("parallelism")\
                 .create_arc_info_from_stream(self)\
@@ -37,11 +38,15 @@ class Stream:
                 .get_output_streams()
     return streams
 
-  def join_with(self, name=None, stream=None, emits=None, fields=None, options=None):
+  def join_with(self, stream, **kwargs):
+    #transform stream names
     lhs_stream = self
+    kwargs['lhs_stream'] = lhs_stream
     rhs_stream = stream
+    kwargs['rhs_stream'] = rhs_stream
+
     op = OperationHandler(self._app, self.__class__)
-    streams = op.build_multilang_operation("join", name, self, stream, emits, fields, options)\
+    streams = op.build_multilang_operation("join", **kwargs)\
                 .add_operation_properties_to_info("name", "type", "lhs_stream", "rhs_stream", "lhs_fields", "rhs_fields", "join_type")\
                 .create_arc_info_from_stream(lhs_stream, "left")\
                 .create_arc_info_from_stream(rhs_stream, "right")\
@@ -60,9 +65,9 @@ class Stream:
     Helper.write_arc_to_file(arc_hash, self._app._socket)
     return self
 
-  def sink(self, name=None, columns=None, relation=None, scope=None):
+  def sink(self, **kwargs):
     op = OperationHandler(self._app, self.__class__)
-    op.build_multilang_operation("sink", name, columns, relation, scope)\
+    op.build_multilang_operation("sink", **kwargs)\
       .add_operation_properties_to_info("name", "type", "columns", "relation", "scope")\
       .create_arc_info_from_stream(self)\
       .handle_operation()
